@@ -22,7 +22,7 @@ import org.apache.myfaces.view.facelets.tag.AbstractTagLibrary;
 
 /**
  * @author Jacob Hookom
- * @version $Id: AbstractHtmlLibrary.java 1187701 2011-10-22 12:21:54Z bommel $
+ * @version $Id$
  */
 public abstract class AbstractHtmlLibrary extends AbstractTagLibrary
 {
@@ -34,6 +34,11 @@ public abstract class AbstractHtmlLibrary extends AbstractTagLibrary
     {
         super(namespace);
     }
+    
+    public AbstractHtmlLibrary(String namespace, String aliasNamespace)
+    {
+        super(namespace, aliasNamespace);
+    }    
 
     public void addHtmlComponent(String name, String componentType, String rendererType)
     {
